@@ -1,6 +1,5 @@
 
 use tokio::runtime::Runtime;
-use async_trait::async_trait;
 use anthill_di::{DependencyContext, types::BuildDependencyResult, Constructor, DependencyLifeCycle};
 
 use criterion::{criterion_group, Criterion};
@@ -10,7 +9,7 @@ struct TransientDependency {
     pub str: String,
 }
 
-#[async_trait]
+#[async_trait_with_sync::async_trait(Sync)]
 impl Constructor for TransientDependency {
     async fn ctor(_: anthill_di::DependencyContext) ->  BuildDependencyResult<Self> {
         Ok(Self { str: "test".to_string() })
