@@ -1,6 +1,5 @@
 use std::any::Any;
 
-use async_trait::async_trait;
 use derive_new::new;
 
 use crate::{
@@ -14,7 +13,7 @@ pub (crate) struct ComponentFromClosure<TComponent: Sync + Send + 'static> {
     closure: Box<dyn Fn(DependencyContext) -> BuildDependencyResult<TComponent> + Sync + Send>
 }
 
-#[async_trait]
+#[async_trait_with_sync::async_trait(Sync)]
 impl<TComponent: Sync + Send + 'static> TypeConstructor for ComponentFromClosure<TComponent> {
     async fn ctor(&self, ctx: DependencyContext) -> BuildDependencyResult<Box<dyn Any + Sync + Send>> {
         let build_result = (self.closure)(ctx)?;
