@@ -1,6 +1,5 @@
 use std::any::Any;
 
-use async_trait::async_trait;
 use tokio::sync::RwLock;
 
 use crate::{
@@ -12,7 +11,6 @@ use crate::{
     }
 };
 
-
 pub (crate) struct ComponentFromInstance<TComponent: Sync + Send + 'static> {
     instance: RwLock<Option<TComponent>>,
 }
@@ -21,7 +19,7 @@ impl<TComponent: Sync + Send> ComponentFromInstance<TComponent> {
     pub (crate) fn new(instance: TComponent) -> Self { Self { instance: RwLock::new(Some(instance)) } }
 }
 
-#[async_trait]
+#[async_trait_with_sync::async_trait(Sync)]
 impl<TComponent: Sync + Send + 'static> TypeConstructor for ComponentFromInstance<TComponent> {
     async fn ctor(&self, _: DependencyContext) -> BuildDependencyResult<Box<dyn Any + Sync + Send>> {
         let instance = self.instance.write().await.take().expect(&format!("Double request registered instance. Expected single request for singleton TypeInfo:[{type_info:?}]", type_info = TypeInfo::from_type::<TComponent>()));
