@@ -1,4 +1,3 @@
-use async_trait::async_trait;
 use tokio::sync::RwLock;
 
 use crate::{
@@ -6,19 +5,19 @@ use crate::{
     types::BuildDependencyResult
 };
 
-#[async_trait]
+#[async_trait_with_sync::async_trait(Sync)]
 pub trait Constructor where Self: Sized + 'static {
     async fn ctor(ctx: DependencyContext) -> BuildDependencyResult<Self>;
 }
 
-#[async_trait]
+#[async_trait_with_sync::async_trait(Sync)]
 impl <T: Constructor + Sized + 'static> Constructor for tokio::sync::RwLock<T> {
     async fn ctor(ctx: DependencyContext) -> BuildDependencyResult<Self> {
         Ok(RwLock::new(T::ctor(ctx).await?))
     }
 }
 
-#[async_trait]
+#[async_trait_with_sync::async_trait(Sync)]
 impl <T: Constructor + Sized + 'static> Constructor for std::sync::RwLock<T> {
     async fn ctor(ctx: DependencyContext) -> BuildDependencyResult<Self> {
         Ok(std::sync::RwLock::new(T::ctor(ctx).await?))
