@@ -1,5 +1,3 @@
-use async_trait::async_trait;
-
 use crate::{
     Constructor,
     types::BuildDependencyResult,
@@ -10,7 +8,7 @@ struct TransientDependency1 {
     pub d2: TransientDependency2,
 }
 
-#[async_trait]
+#[async_trait_with_sync::async_trait(Sync)]
 impl Constructor for TransientDependency1 {
     async fn ctor(ctx: crate::DependencyContext) -> BuildDependencyResult<Self> {
         Ok(Self {
@@ -24,7 +22,7 @@ struct TransientDependency2 {
     pub d1: Box<TransientDependency1>,
 }
 
-#[async_trait]
+#[async_trait_with_sync::async_trait(Sync)]
 impl Constructor for TransientDependency2 {
     async fn ctor(ctx: crate::DependencyContext) ->  BuildDependencyResult<Self> {
         Ok(Self {
