@@ -2,4 +2,7 @@ mod result;
 pub use result::*;
 
 mod async_callback;
-pub use async_callback::*;
\ No newline at end of file
+pub use async_callback::*;
+
+mod type_info;
+pub use type_info::*;
\ No newline at end of file
